@@ -2,13 +2,14 @@ from lago_python_client.models.applied_add_on import AppliedAddOn
 from lago_python_client.models.applied_coupon import AppliedCoupon
 from lago_python_client.models.billable_metric import BillableMetric, BillableMetricGroup
 from lago_python_client.models.coupon import Coupon, LimitationConfiguration
+from lago_python_client.models.credit import CreditResponse, CreditsResponse, InvoiceItemResponse
 from lago_python_client.models.credit_note import Item, Items, CreditNote, CreditNoteUpdate
 from lago_python_client.models.plan import Plan, Charges, Charge
 from lago_python_client.models.add_on import AddOn
 from lago_python_client.models.organization import Organization, OrganizationBillingConfiguration
 from lago_python_client.models.event import Event, BatchEvent
-from lago_python_client.models.customer import Customer, CustomerBillingConfiguration
-from lago_python_client.models.invoice import InvoicePaymentStatusChange
+from lago_python_client.models.customer import Customer, CustomerBillingConfiguration, Metadata, MetadataList
+from lago_python_client.models.invoice import InvoicePaymentStatusChange, Invoice, InvoiceMetadata, InvoiceMetadataList
 from lago_python_client.models.subscription import Subscription
 from lago_python_client.models.customer_usage import Metric, ChargeObject, ChargeUsage, CustomerUsageResponse
 from lago_python_client.models.wallet import Wallet
