@@ -2,6 +2,10 @@ from pydantic import BaseModel, Field
 from typing import Optional
 
 
+class LimitationConfiguration(BaseModel):
+    plan_codes: Optional[list]
+
+
 class Coupon(BaseModel):
     name: Optional[str]
     code: Optional[str]
@@ -14,6 +18,7 @@ class Coupon(BaseModel):
     reusable: Optional[bool]
     frequency: Optional[str]
     frequency_duration: Optional[int]
+    applies_to: Optional[LimitationConfiguration]
 
 
 class CouponResponse(BaseModel):
@@ -30,3 +35,5 @@ class CouponResponse(BaseModel):
     reusable: Optional[bool]
     frequency: Optional[str]
     frequency_duration: Optional[int]
+    plan_codes: Optional[list]
+    limited_plans: Optional[bool]
