@@ -1,11 +1,16 @@
 from pydantic import BaseModel, Field
 from typing import Optional, List, Union
 
+class GroupProperties(BaseModel):
+    group_id: Optional[str]
+    values: Optional[dict]
+
 class Charge(BaseModel):
     id: Optional[str]
     billable_metric_id: Optional[str]
     charge_model: Optional[str]
-    properties: Optional[Union[dict, list]]
+    properties: Optional[dict]
+    group_properties: Optional[GroupProperties]
 
 class Charges(BaseModel):
     __root__: List[Charge]
@@ -36,3 +41,5 @@ class PlanResponse(BaseModel):
     pay_in_advance: Optional[bool]
     bill_charges_monthly: Optional[bool]
     charges: Optional[Charges]
+    active_subscriptions_count: int
+    draft_invoices_count: int
