@@ -3,13 +3,13 @@ import requests_mock
 import os
 
 from lago_python_client.client import Client
+from lago_python_client.exceptions import LagoApiError
 from lago_python_client.models import Subscription
-from lago_python_client.clients.base_client import LagoApiError
 
 
 def create_subscription():
-    return Subscription(customer_id='5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba', plan_code='eartha lynch',
-                        unique_id='code', billing_time='anniversary')
+    return Subscription(external_customer_id='5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba', plan_code='eartha lynch',
+                        external_id='code', billing_time='anniversary', subscription_date='2022-04-29')
 
 
 def mock_response():
@@ -36,10 +36,11 @@ class TestSubscriptionClient(unittest.TestCase):
             m.register_uri('POST', 'https://api.getlago.com/api/v1/subscriptions', text=mock_response())
             response = client.subscriptions().create(create_subscription())
 
-        self.assertEqual(response.customer_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')
+        self.assertEqual(response.external_customer_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')
         self.assertEqual(response.status, 'active')
         self.assertEqual(response.plan_code, 'eartha lynch')
         self.assertEqual(response.billing_time, 'anniversary')
+        self.assertEqual(response.subscription_date, '2022-04-29')
 
     def test_invalid_create_subscriptions_request(self):
         client = Client(api_key='invalid')
@@ -60,10 +61,11 @@ class TestSubscriptionClient(unittest.TestCase):
                            text=mock_response())
             response = client.subscriptions().update(Subscription(name='name'), identifier)
 
-        self.assertEqual(response.customer_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')
+        self.assertEqual(response.external_customer_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')
         self.assertEqual(response.status, 'active')
         self.assertEqual(response.plan_code, 'eartha lynch')
         self.assertEqual(response.billing_time, 'anniversary')
+        self.assertEqual(response.subscription_date, '2022-04-29')
 
     def test_invalid_update_subscription_request(self):
         client = Client(api_key='invalid')
@@ -86,7 +88,7 @@ class TestSubscriptionClient(unittest.TestCase):
             m.register_uri('DELETE', 'https://api.getlago.com/api/v1/subscriptions/' + identifier, text=mock_response())
             response = client.subscriptions().destroy(identifier)
 
-        self.assertEqual(response.customer_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')
+        self.assertEqual(response.external_customer_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')
         self.assertEqual(response.status, 'active')
         self.assertEqual(response.plan_code, 'eartha lynch')
 
@@ -105,9 +107,9 @@ class TestSubscriptionClient(unittest.TestCase):
         client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
 
         with requests_mock.Mocker() as m:
-            m.register_uri('GET', 'https://api.getlago.com/api/v1/subscriptions?customer_id=123',
+            m.register_uri('GET', 'https://api.getlago.com/api/v1/subscriptions?external_customer_id=123',
                            text=mock_collection_response())
-            response = client.subscriptions().find_all({'customer_id': '123'})
+            response = client.subscriptions().find_all({'external_customer_id': '123'})
 
         self.assertEqual(response['subscriptions'][0].lago_id, 'b7ab2926-1de8-4428-9bcd-779314ac129b')
         self.assertEqual(response['meta']['current_page'], 1)
